@@ -5,7 +5,7 @@ use Class::Autouse_1_99_02;
 use Command;
 use Command::DynamicSubCommands;
 use UR;
-our $VERSION = $UR::VERSION;
+our $VERSION = "0.26"; # UR $VERSION;
 use UR::BoolExpr;
 use UR::BoolExpr::Template;
 use UR::BoolExpr::Template::And;
@@ -78,7 +78,6 @@ use UR::Env::UR_DBI_NO_COMMIT;
 use UR::Env::UR_DEBUG_OBJECT_PRUNING;
 use UR::Env::UR_DEBUG_OBJECT_RELEASE;
 use UR::Env::UR_IGNORE;
-use UR::Env::UR_MOOSE;
 use UR::Env::UR_NR_CPU;
 use UR::Env::UR_STACK_DUMP_ON_DIE;
 use UR::Env::UR_STACK_DUMP_ON_WARN;
@@ -91,7 +90,6 @@ use UR::Exit;
 use UR::ModuleBase;
 use UR::ModuleConfig;
 use UR::ModuleLoader;
-use UR::Moose;
 use UR::Namespace;
 use UR::Namespace::Command;
 use UR::Namespace::Command::Define;
