@@ -28,7 +28,7 @@ This module subclasses DBI, and provides a few extra methods useful when using a
 require 5.006_000;
 use warnings;
 use strict;
-our $VERSION = "0.46"; # UR $VERSION;
+our $VERSION = "0.26"; # UR $VERSION;;
 
 # set up module
 use base qw(Exporter DBI);
@@ -322,9 +322,6 @@ sub before_execute
 	$monitor_dml=2;
     }
     no warnings;            
-    
-    UR::DBI::log_sql_for_summary($sql);    # $ENV{UR_DBI_SUMMARIZE_SQL}
-
     my $log_sql_str = _generate_sql_and_params_log_entry($sql, @_);
     UR::DBI::log_sql($log_sql_str);
     return $start_time;
@@ -449,25 +446,11 @@ sub after_all_fetches_no_sth {
 }
 
 
-my $__SQL_SUMMARY__ = {};
-sub log_sql_for_summary {
-    my ($sql) = @_;
-    $__SQL_SUMMARY__->{$sql}++; 
-}
-
-sub print_sql_summary {
-    for my $sql (sort {$__SQL_SUMMARY__->{$b} <=> $__SQL_SUMMARY__->{$a}} keys %$__SQL_SUMMARY__) {
-        print STDERR join('',"********************\n", $__SQL_SUMMARY__->{$sql}, " instances of query: $sql\n");
-    }
-}
-
 # These methods are called by the above.
 
 sub _generate_sql_and_params_log_entry 
 {
-
     my $sql = shift;
-
     no warnings;
     my $sql_log_str =  "\nSQL: $sql\n"; 
     if (@_) {
@@ -567,7 +550,7 @@ sub _print_query_plan
     
     $dbh->do($UR::DBI::EXPLAIN_PLAN_DML . "\n" . $sql)
         or die "Failed to produce query plan! " . $dbh->errstr;        
-    UR::DBI::Report->generate(
+    UR::Report->generate(
         sql => [$UR::DBI::EXPLAIN_PLAN_SQL],
         dbh => $dbh,
         count => 0,
@@ -673,15 +656,13 @@ sub rollback_without_object_update
 sub disconnect
 {
     my $self = shift;
-    # Rollback if AutoCommit is 0.  Oracle commits by default on disconnect.
-    # Rolling back when AutoCommit is on will generate a DBI warning.
-    if ($self->{'AutoCommit'} == 0) {
-        $self->rollback;    
-    }
+    
+    # Always rollback.  Oracle commits by default on disconnect.
+    $self->rollback;    
     
     # Msg and disconnect.
     UR::DBI::before_execute("disconnecting");
-    my $rv = $self->SUPER::disconnect(@_);
+    $self->SUPER::disconnect(@_);
     UR::DBI::after_execute();
     
     # There doesn't seem to be anything less which
@@ -696,7 +677,6 @@ sub disconnect
         $UR::DBI::common_dbh = undef;
         UR::DBI::after_execute("common dbh removed");
     }
-    return $rv;
 }
 
 sub prepare
@@ -827,10 +807,14 @@ use warnings;
 
 use Time::HiRes;
 use Sys::Hostname;
-use Devel::GlobalDestruction;
 
 our @ISA = qw(DBI::st);
 
+our $global_destruction = 0;
+END {
+    $global_destruction = 1;
+}
+
 sub _mk_mutator {
     my ($class, $method) = @_;
 
@@ -841,10 +825,9 @@ sub _mk_mutator {
     $hash_key =~ s/::/_/g;
 
     my $sub = sub {
-        return if Devel::GlobalDestruction::in_global_destruction;
+        return if $global_destruction;
         my $sth = shift;
         if (@_) {
-            no warnings 'uninitialized';
             $sth->{$hash_key} = shift;
         }
         no warnings;
