@@ -3,14 +3,14 @@ use warnings;
 
 package UR::DataSource::RDBMS::Table;
 
-use UR;
-our $VERSION = "0.44_01"; # UR $VERSION;
-
+use UR::Object::Type;
+our $VERSION = "0.26"; # UR $VERSION;
 UR::Object::Type->define(
     class_name => 'UR::DataSource::RDBMS::Table',
     is => ['UR::DataSource::RDBMS::Entity'],
+    english_name => 'dd table',
     dsmap => 'dd_table',
-    id_properties => [qw/data_source table_name/],
+    id_properties => [qw/data_source owner table_name/],
     properties => [
         data_source                      => { type => 'varchar', len => undef, sql => 'data_source' },
         data_source_obj                  => { type => 'UR::DataSource', id_by => 'data_source'}, 
@@ -18,7 +18,7 @@ UR::Object::Type->define(
                                               calculate => q( (split(/::/,$data_source))[0] ) },
         owner                            => { type => 'varchar', len => undef, is_optional => 1, sql => 'owner' },
         table_name                       => { type => 'varchar', len => undef, sql => 'table_name' },
-        er_type                          => { type => 'varchar', len => undef, sql => 'er_type', is_optional => 1 },
+        er_type                          => { type => 'varchar', len => undef, sql => 'er_type' },
         last_ddl_time                    => { type => 'timestamp', len => undef, sql => 'last_ddl_time', is_optional => 1 },
         last_object_revision             => { type => 'timestamp', len => undef, sql => 'last_object_revision' },
         remarks                          => { type => 'varchar', len => undef, is_optional => 1, sql => 'remarks' },
@@ -28,8 +28,7 @@ UR::Object::Type->define(
 );
 
 sub _related_class_name {
-    my($self,$subject) = @_;
-
+my($self,$subject) = @_;
     my $class = ref($self);  
     
     # FIXME  This seems kinda braindead, but is probably faster than using s///
@@ -61,7 +60,7 @@ sub _bitmap_index_class {
 }
 
 sub columns {
-    my $self = shift;
+my $self = shift;
 
     my $col_class = $self->_table_column_class;
     return $col_class->get(data_source => $self->data_source, table_name => $self->table_name);
@@ -72,27 +71,24 @@ sub column_names {
 }
 
 sub primary_key_constraint_columns {
-    my $self = shift;
+my $self = shift;
 
     my $pk_class = $self->_pk_constraint_class;
     my @pks = $pk_class->get(data_source => $self->data_source, table_name  => $self->table_name);
-    my @pks_with_rank = map { [ $_->rank, $_ ] } @pks;
-    return map { $_->[1] }
-           sort { $a->[0] <=> $b->[0] }
-           @pks_with_rank;
+    return sort { $a->rank <=> $b->rank } @pks;
 }
 
 
 sub primary_key_constraint_column_names {
-    return map { $_->column_name } shift->primary_key_constraint_columns;
+    return map { uc($_->column_name) } shift->primary_key_constraint_columns;
 }
 
 
 sub fk_constraints {
-    my $self = shift;
+my $self = shift;
 
     my $fk_class = $self->_fk_constraint_class;
-    my @fks = $fk_class->get(data_source => $self->data_source, table_name => $self->table_name);
+    my @fks = $fk_class->get(data_source => $self->data_source, table_name => $self->table_name, owner => $self->owner);
     return @fks;
 }
 
@@ -102,10 +98,10 @@ sub fk_constraint_names {
 
 
 sub ref_fk_constraints {
-    my $self = shift;
+my $self = shift;
 
     my $fk_class = $self->_fk_constraint_class;
-    my @fks = $fk_class->get(data_source => $self->data_source, r_table_name => $self->table_name);
+    my @fks = $fk_class->get(data_source => $self->data_source, r_table_name => $self->table_name, r_owner => $self->owner);
     return @fks;
 }
 
@@ -115,7 +111,7 @@ sub ref_fk_constraint_names {
 
 
 sub unique_constraint_column_names {
-    my($self,$constraint) = @_;
+my($self,$constraint) = @_;
 
     my @c;
     if ($constraint) {
@@ -128,15 +124,13 @@ sub unique_constraint_column_names {
 }
 
 sub unique_constraint_names {
-    my $self = shift;
-
+my $self = shift;
     my %names = map { $_->constraint_name => 1 } $self->unique_constraints;
     return keys %names;
 }
 
 sub unique_constraints {
-    my $self = shift;
-
+my $self = shift;
     my $uc_class = $self->_unique_constraint_class;
     my @c = $uc_class->get( data_source => $self->data_source, table_name => $self->table_name, @_);
 
@@ -144,7 +138,7 @@ sub unique_constraints {
 }
 
 sub bitmap_indexes {
-    my $self = shift;
+my $self = shift;
 
     my $bi_class = $self->_bitmap_index_class;
     my @bi = $bi_class->get(data_source => $self->data_source, table_name => $self->table_name);
@@ -159,19 +153,17 @@ sub bitmap_index_names {
 # FIXME Due to a "bug" in getting class objects, you need to pass in namespace => 'name' as
 # arguments to get this to work.
 sub handler_class {
-    my $self = shift;
-
+my $self = shift;
     return UR::Object::Type->get(table_name => $self->table_name, @_);
 }
 
 sub handler_class_name {
     my $self = shift;
-
     return $self->handler_class(@_)->class_name;
 }
 
 sub delete {
-    my $self = shift;
+my $self = shift;
 
     my @deleteme = ( $self->fk_constraints,
                      $self->bitmap_indexes,
