@@ -37,10 +37,15 @@ UR::Object::Type->define(
 
 sub driver { "SQLite" }
 
-sub owner {
+sub default_owner {
+    unless (defined $DBD::SQLite::VERSION) {
+        require DBD::SQLite;
+    }
     $DBD::SQLite::VERSION < 1.26_04 ? undef : 'main' 
 }
 
+sub owner { default_owner() }
+
 sub login {
     undef
 }
@@ -86,12 +91,23 @@ sub _data_dump_path {
 sub server {
     my $self = shift->_singleton_object();
     my $path = $self->__meta__->module_path;
-    $path =~ s/\.pm$/.sqlite3/ or Carp::confess("Odd module path $path");
+    my $ext = $self->_extension_for_db;
+    $path =~ s/\.pm$/$ext/ or Carp::confess("Odd module path $path");
+
     my $dir = File::Basename::dirname($path);
     return $path; 
 }
 *_database_file_path = \&server;
 
+
+# More recent versions of SQLite support enforced foreign keys
+# and have slightly different dump text.  We'll give the new
+# ones a different extension.
+sub _extension_for_db {
+    my $self = shift;
+    $self->default_owner ? '.sqlite3n' : '.sqlite3';
+}
+
 sub _journal_file_path {
     my $self = shift->_singleton_object();
     return $self->server . "-journal";
