@@ -2,6 +2,8 @@ package UR::Namespace::View::SchemaBrowser::CgiApp;
 
 use strict;
 use warnings;
+require UR;
+our $VERSION = "0.26"; # UR $VERSION;
 
 UR::Object::Type->define(
     class_name => 'UR::Namespace::View::SchemaBrowser::CgiApp',
@@ -145,6 +147,7 @@ $DB::single=1;
             last;
         }
     }
+    no warnings;
     my $ref = $class_name->can($method_name);
 }
             
