@@ -3,6 +3,7 @@ package UR::Object::Set;
 use strict;
 use warnings;
 use UR;
+our $VERSION = "0.26"; # UR $VERSION;
 
 class UR::Object::Set {
     is => 'UR::Value',
@@ -11,7 +12,7 @@ class UR::Object::Set {
         rule                => { is => 'UR::BoolExpr', id_by => 'id' },
         rule_display        => { via => 'rule', to => '__display_name__'},
         member_class_name   => { via => 'rule', to => 'subject_class_name' },
-        members             => { is => 'UR::Object' }
+        members             => { is => 'UR::Object', is_many => 1 }
     ],
     doc => 'an unordered group of distinct UR::Objects'
 };
