@@ -1,7 +1,7 @@
-# Methods for setting transient attributes on objects.
-
 package UR::Object::Tag;
 
+#TODO: update these to be UR::Value objects instead of some ancient hack
+
 =pod
 
 =head1 NAME
@@ -117,7 +117,7 @@ object.
 require 5.006_000;
 use warnings;
 use strict;
-our $VERSION = $UR::VERSION; 
+our $VERSION = "0.26"; # UR $VERSION; 
 
 # set up module
 use base qw(UR::ModuleBase);
@@ -162,6 +162,16 @@ sub filter
     return $filter;
 }
 
+sub __display_name__ {
+    my $self = $_[0];
+    my $msg = uc($self->type) . ": " . $self->desc;
+    my @properties = $self->properties;
+    if (@properties) {
+        $msg .= " on " . join(",",@properties);
+    }
+    return $msg;
+}
+
 1;
 __END__
 
