@@ -2,6 +2,8 @@ package UR::Object::View::Default::Xsl;
 
 use strict;
 use warnings;
+require UR;
+our $VERSION = "0.26"; # UR $VERSION;
 use IO::File;
 
 use XML::LibXML;
@@ -31,7 +33,8 @@ use Exporter 'import';
 our @EXPORT_OK = qw(type_to_url url_to_type);
 
 sub _generate_content {
-    my $self = shift;
+
+    my ($self, %params) = @_;
 
     if (!$self->desired_perspective) {
         $self->desired_perspective($self->perspective);
@@ -49,14 +52,16 @@ sub _generate_content {
         $xml_view = UR::Object::View->create(
             subject_class_name => $self->subject_class_name,
             perspective => $self->desired_perspective,
-            toolkit => 'xml'
+            toolkit => 'xml',
+            %params
         );
     };
     if ($@) {
         $xml_view = UR::Object::View->create(
             subject_class_name => $self->subject_class_name,
             perspective => $self->perspective,
-            toolkit => 'xml'
+            toolkit => 'xml',
+            %params
         );
     }
 
