@@ -1,7 +1,5 @@
 
 package CdExample::Artist;
-use strict;
-use warnings;
 use CdExample;
 
 class CdExample::Artist {
