@@ -7,9 +7,7 @@ use UR;
 
 class URT {
     is => ['UR::Namespace'],
-    has_constant => [
-        allow_sloppy_primitives => { value => 1 },
-    ],
+    type_name => 'urt',
     doc => 'A dummy namespace used by the UR test suite.',
 };
 
